//LabPlot : InfoDialog.h

#ifndef INFODIALOG_H
#define INFODIALOG_H

#include <qfont.h>
#include <qcheckbox.h>
#include "Dialog.h"

class InfoDialog: public Dialog
{
public:
	InfoDialog(MainWin *m, const char *name, int item);
};

#endif //INFODIALOG_H
